@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -19,9 +19,7 @@ ConfigureCustomSettingWidgetTest::ConfigureCustomSettingWidgetTest(QObject *pare
 {
 }
 
-ConfigureCustomSettingWidgetTest::~ConfigureCustomSettingWidgetTest()
-{
-}
+ConfigureCustomSettingWidgetTest::~ConfigureCustomSettingWidgetTest() = default;
 
 void ConfigureCustomSettingWidgetTest::shouldHaveDefaultValue()
 {
