@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -18,9 +18,7 @@ CustomDebugSettingsPageTest::CustomDebugSettingsPageTest(QObject *parent)
 {
 }
 
-CustomDebugSettingsPageTest::~CustomDebugSettingsPageTest()
-{
-}
+CustomDebugSettingsPageTest::~CustomDebugSettingsPageTest() = default;
 
 void CustomDebugSettingsPageTest::shouldHaveDefaultValue()
 {
