@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -22,9 +22,7 @@ KDebugSettingsDialogTest::KDebugSettingsDialogTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 }
 
-KDebugSettingsDialogTest::~KDebugSettingsDialogTest()
-{
-}
+KDebugSettingsDialogTest::~KDebugSettingsDialogTest() = default;
 
 void KDebugSettingsDialogTest::shouldHaveDefaultValue()
 {
