@@ -19,6 +19,7 @@
 #include <QPointer>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <kwidgetsaddons_version.h>
 
 CustomDebugSettingsPage::CustomDebugSettingsPage(QWidget *parent)
     : QWidget(parent)
@@ -88,7 +89,7 @@ bool CustomDebugSettingsPage::eventFilter(QObject *obj, QEvent *event)
 void CustomDebugSettingsPage::slotCustomContextMenu(const QPoint &pos)
 {
     QMenu menu(this);
-    const int selectedItemCount{mListWidget->selectedItems().count()};
+    const auto selectedItemCount{mListWidget->selectedItems().count()};
     menu.addAction(QIcon::fromTheme(QStringLiteral("list-add")), i18n("Add Rule..."), this, &CustomDebugSettingsPage::slotAddRule);
     if (selectedItemCount == 1) {
         menu.addAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18n("Edit Rule"), this, &CustomDebugSettingsPage::slotEditRule);
@@ -182,7 +183,12 @@ void CustomDebugSettingsPage::slotRemoveRules()
     }
     const QString str = i18np("Do you want to remove this rule?", "Do you want to remove these %1 rules?", lst.count());
 
-    if (KMessageBox::No == KMessageBox::warningYesNo(this, str)) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (KMessageBox::ButtonCode::SecondaryAction
+        == KMessageBox::warningTwoActions(this, str, i18n("Remove Rule"), KStandardGuiItem::remove(), KStandardGuiItem::cancel())) {
+#else
+    if (KMessageBox::No == KMessageBox::warningYesNo(this, str, i18n("Remove Rule"), KStandardGuiItem::remove())) {
+#endif
         return;
     }
     for (int i = 0; i < lst.count(); ++i) {
