@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -24,9 +24,7 @@ EnvironmentSettingsRulesPage::EnvironmentSettingsRulesPage(QWidget *parent)
     mainLayout->addWidget(mRichTextEdit);
 }
 
-EnvironmentSettingsRulesPage::~EnvironmentSettingsRulesPage()
-{
-}
+EnvironmentSettingsRulesPage::~EnvironmentSettingsRulesPage() = default;
 
 void EnvironmentSettingsRulesPage::setRules(const QString &rules)
 {
