@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,9 +8,7 @@
 #include "loadcategoriesjob.h"
 #include "kdebugsettingsutil.h"
 
-LoadCategoriesJob::LoadCategoriesJob()
-{
-}
+LoadCategoriesJob::LoadCategoriesJob() = default;
 
 void LoadCategoriesJob::setFileName(const QString &filename)
 {
