@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -7,9 +7,7 @@
 
 #include "loggingcategory.h"
 
-LoggingCategory::LoggingCategory()
-{
-}
+LoggingCategory::LoggingCategory() = default;
 
 bool LoggingCategory::operator==(const LoggingCategory &other) const
 {
