@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -10,9 +10,7 @@
 #include <QFile>
 #include <QTextStream>
 
-SaveRulesJob::SaveRulesJob()
-{
-}
+SaveRulesJob::SaveRulesJob() = default;
 
 void SaveRulesJob::setListKde(const LoggingCategory::List &listKde)
 {
