@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -24,6 +24,4 @@ SaveToolButton::SaveToolButton(QWidget *parent)
     connect(actGroup, &QAction::triggered, this, &SaveToolButton::saveAsGroup);
 }
 
-SaveToolButton::~SaveToolButton()
-{
-}
+SaveToolButton::~SaveToolButton() = default;
